package fr.cnrs.mri.util;

import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Observable;
import java.util.logging.Logger;
import java.util.zip.Deflater;

import fr.cnrs.mri.util.logging.LoggingUtil;

public abstract class ZIPUtil extends Observable{

	private Integer compressionLevel = Deflater.BEST_COMPRESSION;
	private ArrayList<ZipEntryWithPath> zipEntries;
	protected int bufferSize = 3145728;
	
	protected OutputStream outputStream;
	
	protected File outputFile;
	/**
	 * To store the progress of zip process, in bytes
	 */
	protected long progress;
	
	private boolean isCanceled;

	abstract public long compress();
	
	public ArrayList<ZipEntryWithPath> getZipEntries() {
		return zipEntries;
	}

	public Integer getCompressionLevel() {
		return compressionLevel;
	}

	public void setCompressionLevel(Integer compressionLevel) {
		this.compressionLevel = compressionLevel;
	}

	public long getTotalFileSize() {
		long result = 0;
		for (ZipEntryWithPath entry : this.getZipEntries()) 
			result += new File(entry.getPath()).length();
		return result;
	}
	
	protected void notifyProgress(long newProgress) {
		this.setProgress(newProgress);
		setChanged();
		notifyObservers();
		clearChanged();
	}

	public int getBufferSize() {
		return bufferSize;
	}

	public void setBufferSize(int bufferSize) {
		this.bufferSize = bufferSize;
	}

	protected void setZipEntries(ArrayList<ZipEntryWithPath> entries) {
		this.zipEntries = entries;
	}

	public Logger getLogger() {
		return LoggingUtil.getLoggerFor(this);
	}

	public long getProgress() {
		return progress;
	}

	public void setProgress(long progress) {
		this.progress = progress;
	}

	public void cancelZipCreation() {
		System.out.println("Cancel zip creation generic");
		try {
			outputStream.close();
			outputFile.delete();
		} catch (IOException e) {
			e.printStackTrace();
		}
		setCanceled(true);
	}

	public boolean isCanceled() {
		return isCanceled;
	}

	public void setCanceled(boolean isCanceled) {
		this.isCanceled = isCanceled;
	}
}
